import { BasicColumn, FormSchema } from '/@/components/Table';
import { optionsListApi, optionTypeListApi } from '/@/api/tigerapi/wms/purchase';
import { h, unref } from 'vue';
import { Tag } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
const { t: bt } = useI18n();
const { getLocale } = useLocale();

export const columns: BasicColumn[] = [
  {
    title: '单据代码',
    resizable: true,
    sorter: true,
    dataIndex: 'BILLCODE',
    width: 200,
  },
  {
    title: '单据日期',
    resizable: true,
    sorter: true,
    dataIndex: 'BILLDATE',
    width: 180,
  },
  {
    title: '创建时间',
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: '操作时间',
    resizable: true,
    sorter: true,
    dataIndex: 'UPDATE_TIME',
    width: 180,
  },
  {
    title: bt('T100单据代码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ERP_BILL_CODE',
    width: 180,
  },
  {
    title: '状态',
    resizable: true,
    sorter: true,
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 1:
          text = '新建\\开立';
          color = 'blue';
          break;
        case 2:
          text = '作业中';
          color = '#C2C247';
          break;
        case 6:
          text = '完成';
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '供应商',
    resizable: true,
    sorter: true,
    dataIndex: 'SUPPLIERCODE',
    width: 180,
  },
  {
    title: '创建人',
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_USER',
    width: 180,
  },

];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: '单据代码',
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'BILLDATE',
    label: '单据日期',
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: '状态',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
    },
  },
];

//领料单(WMS)明细
export const columns_D: BasicColumn[] = [

  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'MATERIALCODE',
    width: 200,
  },
  {
    title: '操作时间',
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  // {
  //   title: bt('单据类型'),
  //   resizable:true,
  //   width: 180,
  //   customRender: ({ record }) => {
  //     const status = record.BIZTYPE;
  //     var text = '';
  //     var color = '';
  //     switch (status) {
  //       case '1':
  //         text = bt('采购');
  //         color = 'green';
  //         break;
  //       case '2':
  //         text = bt('委外');
  //         color = 'blue';
  //         break;
  //       // case '99':
  //       //   text = '其他';
  //       //   color = '#C2C247';
  //       //   break;
  //       default:
  //         break;
  //     }
  //     return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
  //   },
  // },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'LINESTATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.LINESTATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '新建/开立';
          color = '#C2C247';
          break;
        case 1:
          text = '作业中';
          color = '#C2C247';
          break;
        case 6:
          text = '完成';
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: bt('需求数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'PRQTY',
    width: 200,
  },
]

export const columns_S: BasicColumn[] = [
  {
    title: bt('组织机构授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_ORG',
    width: 200,
    ifShow: false
  },
  {
    title: bt('生产单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_PROD',
    width: 200,
    ifShow: false
  },
  {
    title: bt('仓库单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_WH',
    width: 200,
    ifShow: false
  },
  {
    title: bt('条码'),
    resizable: true,
    sorter: true,
    dataIndex: 'SN',
    width: 200,
  },
  // {
  //   title: bt('单据类型'),
  //   resizable:true,
  //   width: 180,
  //   customRender: ({ record }) => {
  //     const status = record.BIZTYPE;
  //     var text = '';
  //     var color = '';
  //     switch (status) {
  //       case '1':
  //         text = bt('采购');
  //         color = 'green';
  //         break;
  //       case '2':
  //         text = bt('委外');
  //         color = 'blue';
  //         break;
  //       // case '99':
  //       //   text = '其他';
  //       //   color = '#C2C247';
  //       //   break;
  //       default:
  //         break;
  //     }
  //     return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
  //   },
  // },
  // {
  //   title: bt('状态'),
  //   resizable:true,
  //   width: 180,
  //   customRender: ({ record }) => {
  //     console.log('record', record);
  //     const status = record.STATUS;
  //     let text = '';
  //     let color = '';
  //     switch (status) {
  //       case 0:
  //         text = bt('初始化');
  //         color = 'blue';
  //         break;
  //       case 1:
  //         text = bt('清点中');
  //         color = '#C2C247';
  //         break;
  //       case '2':
  //         text = bt('作业中');
  //         color = '#C2C247';
  //         break;
  //       case 3:
  //         text = bt('超发');
  //         color = 'green';
  //         break;
  //       case 4:
  //         text = bt('完成');
  //         color = 'green';
  //         break;
  //       default:
  //         break;
  //     }
  //     return h(Tag, { color: color }, () => text);
  //   },
  // },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: bt('数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'QTY',
    width: 200,
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'MATERIALCODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'LINESTATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  },
  // {
  //   field: 'BIZTYPE',
  //   label: bt('单据类型'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionTypeListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
  //     valueField: 'Value',
  //   },
  // },
];
export const searchFormSchema_S: FormSchema[] = [
  // {
  //   field: 'BILLCODE',
  //   label: bt('单据代码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'SN',
    label: bt('条码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'LINESTATUS',
  //   label: bt('状态'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionsListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
  //     valueField: 'Value',
  //   },
  // },
  {
    field: 'BIZTYPE',
    label: bt('单据类型'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionTypeListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  },
];
